@@ -940,6 +940,7 @@ def cli(
                                                                 "Group name",
                                                             ],
                                                         )
+                                                        
                                                         c_replies = pd.DataFrame(
                                                             replies_list,
                                                             columns=[
@@ -1198,6 +1199,7 @@ def cli(
                                         bar()
 
                                 if reply_analysis is True:
+                                    c_repliers_u = c_repliers["User id"].unique()
                                     if len(replies_list) > 0:
                                         with open(
                                             reply_file_archive, "w+", encoding="utf-8"
@@ -1208,7 +1210,7 @@ def cli(
                                         with open(
                                             reply_memberlist_filename, "w+", encoding="utf-8"
                                         ) as repliers_file:
-                                            c_repliers.to_csv(repliers_file, sep=";")
+                                            c_repliers_u.to_csv(repliers_file, sep=";")
 
                                 with open(
                                     file_archive, "w+", encoding="utf-8"
